This is the mail archive of the cygwin-patches mailing list for the Cygwin project.


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]
Other format: [Raw text]

[PATCH] mntent.h cleanup


-----BEGIN PGP SIGNED MESSAGE-----
Hash: SHA256

According to the ChangeLogs, addmntent and hasmntopt were removed in
1996(!).  Also, update and (hopefully) clarify a comment.


2009-03-24  Yaakov Selkowitz  <yselkowitz@cygwin.com>

	* include/mntent.h: Remove declarations of nonexistant addmntent
	and hasmntopt.  Update and clarify the /etc/mtab comment.


Yaakov
-----BEGIN PGP SIGNATURE-----
Version: GnuPG v1.4.9 (Cygwin)
Comment: Using GnuPG with Mozilla - http://enigmail.mozdev.org

iEYEAREIAAYFAknIf7AACgkQpiWmPGlmQSNwrwCeNcCcYe1vqxvDbjT2OSgLfZdp
91gAmgNzj0TZqlzQ8apv2p09yT7qikBH
=NbWF
-----END PGP SIGNATURE-----
Index: include/mntent.h
===================================================================
RCS file: /cvs/src/src/winsup/cygwin/include/mntent.h,v
retrieving revision 1.4
diff -u -r1.4 mntent.h
--- include/mntent.h	13 Feb 2006 19:01:32 -0000	1.4
+++ include/mntent.h	24 Mar 2009 06:34:09 -0000
@@ -29,18 +29,17 @@
 #include <stdio.h>
 FILE *setmntent (const char *__filep, const char *__type);
 struct mntent *getmntent (FILE *__filep);
-int addmntent (FILE *__filep, const struct mntent *__mnt);
 int endmntent (FILE *__filep);
-char *hasmntopt (const struct mntent *__mnt, const char *__opt);
 #endif
 
-/* This next file doesn't exist, it is in the registry,
-   however applications need the define to pass to
-   the above calls.
+/* This next file does exist, but the implementation of these
+   functions does not actually use it.
+   However, applications need the define to pass to setmntent().
 */
 #ifndef MOUNTED
 #define MOUNTED "/etc/mtab"
 #endif
+
 #ifdef __cplusplus
 };
 #endif

Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]